@@ -1385,7 +1385,7 @@ bool ConfigElem::writeToMailBox( const TQString & mail, const TQString & box )
   if( !isMailDir( mailDir ) )
   {
     //show an error message
-    KMessageBox::error( NULL, i18n( TQString( "%1 is not a mailbox." ).arg( box ) ) );
+    KMessageBox::error( NULL, i18n( "%1 is not a mailbox." ).arg( box ) );
     return false;
   }
 
@@ -1400,7 +1400,7 @@ bool ConfigElem::writeToMailBox( const TQString & mail, const TQString & box )
   {
     //the hostname is not readable
     //show an error message and exit
-    KMessageBox::error( NULL, i18n( TQString( "Can't read the hostname of your computer. But KShowmail need it to write a mail into the mailbox." ) ) );
+    KMessageBox::error( NULL, i18n( "Can't read the hostname of your computer. But KShowmail need it to write a mail into the mailbox." ) );
     return false;
   }
 
@@ -1424,7 +1424,7 @@ bool ConfigElem::writeToMailBox( const TQString & mail, const TQString & box )
   }
   else
   {
-    KMessageBox::detailedError( NULL, i18n( TQString( "Could not file a mail to %1." ) ).arg( box ), i18n( file.errorString() ) );
+    KMessageBox::detailedError( NULL, i18n( "Could not file a mail to %1." ).arg( box ), i18n( file.errorString().utf8() ) );
     return false;
   }
 
@@ -1435,7 +1435,7 @@ bool ConfigElem::writeToMailBox( const TQString & mail, const TQString & box )
 
   if( rename( absFile.ascii(), absNewFile.ascii() ) == -1 )
   {
-    KMessageBox::error( NULL, i18n( TQString( "Could not move a mail from %1 to %2." ) ).arg( absFile ).arg( absNewFile ) );
+    KMessageBox::error( NULL, i18n( "Could not move a mail from %1 to %2." ).arg( absFile ).arg( absNewFile ) );
     return false;
   }
 
@@ -1757,3 +1757,5 @@ void ConfigElem::slotCommitBeforeRefreshDone(TDEIO::Job *)
   //after a commit was send, we start a new refresh cyle
   refreshMailList();
 }
+
+#include "configelem.moc"
